# cleanmagma

- [x] To retrieve the information from GWAS summary statistics file for running magma.
- [x] To run magma with snp to gene annotation, gene level and gene set level enrichment.
- [x] To summarize the results for the same input gmt files (named gene list) enriched to multiple GWAS data and plot a heatmap with rows are given input gmt names and columns are different GWAS file names.

See examples in docs/
